# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six
from kps_api.models.metrics import Metrics  # noqa: F401,E501


class Event(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'audience': 'str',
        'id': 'str',
        'is_encrypted': 'bool',
        'is_infra_entity': 'bool',
        'message': 'str',
        'metrics': 'Metrics',
        'path': 'str',
        'properties': 'dict(str, str)',
        'severity': 'str',
        'source_type': 'str',
        'state': 'str',
        'timestamp': 'datetime',
        'type': 'str',
        'version': 'str'
    }

    attribute_map = {
        'audience': 'audience',
        'id': 'id',
        'is_encrypted': 'isEncrypted',
        'is_infra_entity': 'isInfraEntity',
        'message': 'message',
        'metrics': 'metrics',
        'path': 'path',
        'properties': 'properties',
        'severity': 'severity',
        'source_type': 'sourceType',
        'state': 'state',
        'timestamp': 'timestamp',
        'type': 'type',
        'version': 'version'
    }

    def __init__(self, audience=None, id=None, is_encrypted=None, is_infra_entity=None, message=None, metrics=None, path=None, properties=None, severity=None, source_type=None, state=None, timestamp=None, type=None, version=None):  # noqa: E501
        """Event - a model defined in Swagger"""  # noqa: E501
        self._audience = None
        self._id = None
        self._is_encrypted = None
        self._is_infra_entity = None
        self._message = None
        self._metrics = None
        self._path = None
        self._properties = None
        self._severity = None
        self._source_type = None
        self._state = None
        self._timestamp = None
        self._type = None
        self._version = None
        self.discriminator = None
        if audience is not None:
            self.audience = audience
        if id is not None:
            self.id = id
        if is_encrypted is not None:
            self.is_encrypted = is_encrypted
        if is_infra_entity is not None:
            self.is_infra_entity = is_infra_entity
        if message is not None:
            self.message = message
        if metrics is not None:
            self.metrics = metrics
        if path is not None:
            self.path = path
        if properties is not None:
            self.properties = properties
        if severity is not None:
            self.severity = severity
        if source_type is not None:
            self.source_type = source_type
        if state is not None:
            self.state = state
        if timestamp is not None:
            self.timestamp = timestamp
        if type is not None:
            self.type = type
        if version is not None:
            self.version = version

    @property
    def audience(self):
        """Gets the audience of this Event.  # noqa: E501


        :return: The audience of this Event.  # noqa: E501
        :rtype: str
        """
        return self._audience

    @audience.setter
    def audience(self, audience):
        """Sets the audience of this Event.


        :param audience: The audience of this Event.  # noqa: E501
        :type: str
        """

        self._audience = audience

    @property
    def id(self):
        """Gets the id of this Event.  # noqa: E501


        :return: The id of this Event.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Event.


        :param id: The id of this Event.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def is_encrypted(self):
        """Gets the is_encrypted of this Event.  # noqa: E501


        :return: The is_encrypted of this Event.  # noqa: E501
        :rtype: bool
        """
        return self._is_encrypted

    @is_encrypted.setter
    def is_encrypted(self, is_encrypted):
        """Sets the is_encrypted of this Event.


        :param is_encrypted: The is_encrypted of this Event.  # noqa: E501
        :type: bool
        """

        self._is_encrypted = is_encrypted

    @property
    def is_infra_entity(self):
        """Gets the is_infra_entity of this Event.  # noqa: E501


        :return: The is_infra_entity of this Event.  # noqa: E501
        :rtype: bool
        """
        return self._is_infra_entity

    @is_infra_entity.setter
    def is_infra_entity(self, is_infra_entity):
        """Sets the is_infra_entity of this Event.


        :param is_infra_entity: The is_infra_entity of this Event.  # noqa: E501
        :type: bool
        """

        self._is_infra_entity = is_infra_entity

    @property
    def message(self):
        """Gets the message of this Event.  # noqa: E501


        :return: The message of this Event.  # noqa: E501
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this Event.


        :param message: The message of this Event.  # noqa: E501
        :type: str
        """

        self._message = message

    @property
    def metrics(self):
        """Gets the metrics of this Event.  # noqa: E501


        :return: The metrics of this Event.  # noqa: E501
        :rtype: Metrics
        """
        return self._metrics

    @metrics.setter
    def metrics(self, metrics):
        """Sets the metrics of this Event.


        :param metrics: The metrics of this Event.  # noqa: E501
        :type: Metrics
        """

        self._metrics = metrics

    @property
    def path(self):
        """Gets the path of this Event.  # noqa: E501


        :return: The path of this Event.  # noqa: E501
        :rtype: str
        """
        return self._path

    @path.setter
    def path(self, path):
        """Sets the path of this Event.


        :param path: The path of this Event.  # noqa: E501
        :type: str
        """

        self._path = path

    @property
    def properties(self):
        """Gets the properties of this Event.  # noqa: E501


        :return: The properties of this Event.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._properties

    @properties.setter
    def properties(self, properties):
        """Sets the properties of this Event.


        :param properties: The properties of this Event.  # noqa: E501
        :type: dict(str, str)
        """

        self._properties = properties

    @property
    def severity(self):
        """Gets the severity of this Event.  # noqa: E501


        :return: The severity of this Event.  # noqa: E501
        :rtype: str
        """
        return self._severity

    @severity.setter
    def severity(self, severity):
        """Sets the severity of this Event.


        :param severity: The severity of this Event.  # noqa: E501
        :type: str
        """

        self._severity = severity

    @property
    def source_type(self):
        """Gets the source_type of this Event.  # noqa: E501


        :return: The source_type of this Event.  # noqa: E501
        :rtype: str
        """
        return self._source_type

    @source_type.setter
    def source_type(self, source_type):
        """Sets the source_type of this Event.


        :param source_type: The source_type of this Event.  # noqa: E501
        :type: str
        """

        self._source_type = source_type

    @property
    def state(self):
        """Gets the state of this Event.  # noqa: E501


        :return: The state of this Event.  # noqa: E501
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this Event.


        :param state: The state of this Event.  # noqa: E501
        :type: str
        """

        self._state = state

    @property
    def timestamp(self):
        """Gets the timestamp of this Event.  # noqa: E501


        :return: The timestamp of this Event.  # noqa: E501
        :rtype: datetime
        """
        return self._timestamp

    @timestamp.setter
    def timestamp(self, timestamp):
        """Sets the timestamp of this Event.


        :param timestamp: The timestamp of this Event.  # noqa: E501
        :type: datetime
        """

        self._timestamp = timestamp

    @property
    def type(self):
        """Gets the type of this Event.  # noqa: E501


        :return: The type of this Event.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this Event.


        :param type: The type of this Event.  # noqa: E501
        :type: str
        """

        self._type = type

    @property
    def version(self):
        """Gets the version of this Event.  # noqa: E501


        :return: The version of this Event.  # noqa: E501
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this Event.


        :param version: The version of this Event.  # noqa: E501
        :type: str
        """

        self._version = version

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Event, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Event):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from kps_api.api_client import ApiClient


class HelmApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def helm_application_create(self, chart, values, application, url, authorization, **kwargs):  # noqa: E501
        """Create Helm Application.  # noqa: E501

        Create a Helm Chart based Application.  Use Application APIs to list or delete the application created by using this API  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.helm_application_create(chart, values, application, url, authorization, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param file chart: (required)
        :param file values: (required)
        :param str application: (required)
        :param str url: (required)
        :param str authorization: Format: Bearer <token>, with <token> from login API response. (required)
        :return: CreateDocumentResponseV2
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.helm_application_create_with_http_info(chart, values, application, url, authorization, **kwargs)  # noqa: E501
        else:
            (data) = self.helm_application_create_with_http_info(chart, values, application, url, authorization, **kwargs)  # noqa: E501
            return data

    def helm_application_create_with_http_info(self, chart, values, application, url, authorization, **kwargs):  # noqa: E501
        """Create Helm Application.  # noqa: E501

        Create a Helm Chart based Application.  Use Application APIs to list or delete the application created by using this API  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.helm_application_create_with_http_info(chart, values, application, url, authorization, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param file chart: (required)
        :param file values: (required)
        :param str application: (required)
        :param str url: (required)
        :param str authorization: Format: Bearer <token>, with <token> from login API response. (required)
        :return: CreateDocumentResponseV2
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['chart', 'values', 'application', 'url', 'authorization']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method helm_application_create" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'chart' is set
        if ('chart' not in params or
                params['chart'] is None):
            raise ValueError("Missing the required parameter `chart` when calling `helm_application_create`")  # noqa: E501
        # verify the required parameter 'values' is set
        if ('values' not in params or
                params['values'] is None):
            raise ValueError("Missing the required parameter `values` when calling `helm_application_create`")  # noqa: E501
        # verify the required parameter 'application' is set
        if ('application' not in params or
                params['application'] is None):
            raise ValueError("Missing the required parameter `application` when calling `helm_application_create`")  # noqa: E501
        # verify the required parameter 'url' is set
        if ('url' not in params or
                params['url'] is None):
            raise ValueError("Missing the required parameter `url` when calling `helm_application_create`")  # noqa: E501
        # verify the required parameter 'authorization' is set
        if ('authorization' not in params or
                params['authorization'] is None):
            raise ValueError("Missing the required parameter `authorization` when calling `helm_application_create`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}
        if 'authorization' in params:
            header_params['Authorization'] = params['authorization']  # noqa: E501

        form_params = []
        local_var_files = {}
        if 'chart' in params:
            local_var_files['chart'] = params['chart']  # noqa: E501
        if 'values' in params:
            local_var_files['values'] = params['values']  # noqa: E501
        if 'application' in params:
            form_params.append(('application', params['application']))  # noqa: E501
        if 'url' in params:
            form_params.append(('url', params['url']))  # noqa: E501

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = ['BearerToken']  # noqa: E501

        return self.api_client.call_api(
            '/v1.0/helm/apps', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CreateDocumentResponseV2',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def helm_application_update(self, chart, values, application, url, authorization, id, **kwargs):  # noqa: E501
        """Update Helm Application.  # noqa: E501

        Update a Helm Chart based Application.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.helm_application_update(chart, values, application, url, authorization, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param file chart: (required)
        :param file values: (required)
        :param str application: (required)
        :param str url: (required)
        :param str authorization: Format: Bearer <token>, with <token> from login API response. (required)
        :param str id: ID of the entity (required)
        :return: UpdateDocumentResponseV2
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.helm_application_update_with_http_info(chart, values, application, url, authorization, id, **kwargs)  # noqa: E501
        else:
            (data) = self.helm_application_update_with_http_info(chart, values, application, url, authorization, id, **kwargs)  # noqa: E501
            return data

    def helm_application_update_with_http_info(self, chart, values, application, url, authorization, id, **kwargs):  # noqa: E501
        """Update Helm Application.  # noqa: E501

        Update a Helm Chart based Application.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.helm_application_update_with_http_info(chart, values, application, url, authorization, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param file chart: (required)
        :param file values: (required)
        :param str application: (required)
        :param str url: (required)
        :param str authorization: Format: Bearer <token>, with <token> from login API response. (required)
        :param str id: ID of the entity (required)
        :return: UpdateDocumentResponseV2
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['chart', 'values', 'application', 'url', 'authorization', 'id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method helm_application_update" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'chart' is set
        if ('chart' not in params or
                params['chart'] is None):
            raise ValueError("Missing the required parameter `chart` when calling `helm_application_update`")  # noqa: E501
        # verify the required parameter 'values' is set
        if ('values' not in params or
                params['values'] is None):
            raise ValueError("Missing the required parameter `values` when calling `helm_application_update`")  # noqa: E501
        # verify the required parameter 'application' is set
        if ('application' not in params or
                params['application'] is None):
            raise ValueError("Missing the required parameter `application` when calling `helm_application_update`")  # noqa: E501
        # verify the required parameter 'url' is set
        if ('url' not in params or
                params['url'] is None):
            raise ValueError("Missing the required parameter `url` when calling `helm_application_update`")  # noqa: E501
        # verify the required parameter 'authorization' is set
        if ('authorization' not in params or
                params['authorization'] is None):
            raise ValueError("Missing the required parameter `authorization` when calling `helm_application_update`")  # noqa: E501
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `helm_application_update`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'authorization' in params:
            header_params['Authorization'] = params['authorization']  # noqa: E501

        form_params = []
        local_var_files = {}
        if 'chart' in params:
            local_var_files['chart'] = params['chart']  # noqa: E501
        if 'values' in params:
            local_var_files['values'] = params['values']  # noqa: E501
        if 'application' in params:
            form_params.append(('application', params['application']))  # noqa: E501
        if 'url' in params:
            form_params.append(('url', params['url']))  # noqa: E501

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = ['BearerToken']  # noqa: E501

        return self.api_client.call_api(
            '/v1.0/helm/apps/{id}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='UpdateDocumentResponseV2',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def helm_template(self, chart, values, release, namespace, url, authorization, **kwargs):  # noqa: E501
        """Run Helm Template.  # noqa: E501

        Run Helm Template to render Helm Chart.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.helm_template(chart, values, release, namespace, url, authorization, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param file chart: (required)
        :param file values: (required)
        :param str release: (required)
        :param str namespace: (required)
        :param str url: (required)
        :param str authorization: Format: Bearer <token>, with <token> from login API response. (required)
        :return: HelmTemplateResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.helm_template_with_http_info(chart, values, release, namespace, url, authorization, **kwargs)  # noqa: E501
        else:
            (data) = self.helm_template_with_http_info(chart, values, release, namespace, url, authorization, **kwargs)  # noqa: E501
            return data

    def helm_template_with_http_info(self, chart, values, release, namespace, url, authorization, **kwargs):  # noqa: E501
        """Run Helm Template.  # noqa: E501

        Run Helm Template to render Helm Chart.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.helm_template_with_http_info(chart, values, release, namespace, url, authorization, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param file chart: (required)
        :param file values: (required)
        :param str release: (required)
        :param str namespace: (required)
        :param str url: (required)
        :param str authorization: Format: Bearer <token>, with <token> from login API response. (required)
        :return: HelmTemplateResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['chart', 'values', 'release', 'namespace', 'url', 'authorization']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method helm_template" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'chart' is set
        if ('chart' not in params or
                params['chart'] is None):
            raise ValueError("Missing the required parameter `chart` when calling `helm_template`")  # noqa: E501
        # verify the required parameter 'values' is set
        if ('values' not in params or
                params['values'] is None):
            raise ValueError("Missing the required parameter `values` when calling `helm_template`")  # noqa: E501
        # verify the required parameter 'release' is set
        if ('release' not in params or
                params['release'] is None):
            raise ValueError("Missing the required parameter `release` when calling `helm_template`")  # noqa: E501
        # verify the required parameter 'namespace' is set
        if ('namespace' not in params or
                params['namespace'] is None):
            raise ValueError("Missing the required parameter `namespace` when calling `helm_template`")  # noqa: E501
        # verify the required parameter 'url' is set
        if ('url' not in params or
                params['url'] is None):
            raise ValueError("Missing the required parameter `url` when calling `helm_template`")  # noqa: E501
        # verify the required parameter 'authorization' is set
        if ('authorization' not in params or
                params['authorization'] is None):
            raise ValueError("Missing the required parameter `authorization` when calling `helm_template`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}
        if 'authorization' in params:
            header_params['Authorization'] = params['authorization']  # noqa: E501

        form_params = []
        local_var_files = {}
        if 'chart' in params:
            local_var_files['chart'] = params['chart']  # noqa: E501
        if 'values' in params:
            local_var_files['values'] = params['values']  # noqa: E501
        if 'release' in params:
            form_params.append(('release', params['release']))  # noqa: E501
        if 'namespace' in params:
            form_params.append(('namespace', params['namespace']))  # noqa: E501
        if 'url' in params:
            form_params.append(('url', params['url']))  # noqa: E501

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = ['BearerToken']  # noqa: E501

        return self.api_client.call_api(
            '/v1.0/helm/template', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='HelmTemplateResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six
from kps_api.models.namespace import Namespace  # noqa: F401,E501
from kps_api.models.runtime import Runtime  # noqa: F401,E501
from kps_api.models.workload_item import WorkloadItem  # noqa: F401,E501


class App(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'namespace': 'Namespace',
        'runtimes': 'list[Runtime]',
        'service_names': 'list[str]',
        'workloads': 'list[WorkloadItem]'
    }

    attribute_map = {
        'name': 'name',
        'namespace': 'namespace',
        'runtimes': 'runtimes',
        'service_names': 'serviceNames',
        'workloads': 'workloads'
    }

    def __init__(self, name=None, namespace=None, runtimes=None, service_names=None, workloads=None):  # noqa: E501
        """App - a model defined in Swagger"""  # noqa: E501
        self._name = None
        self._namespace = None
        self._runtimes = None
        self._service_names = None
        self._workloads = None
        self.discriminator = None
        self.name = name
        self.namespace = namespace
        if runtimes is not None:
            self.runtimes = runtimes
        self.service_names = service_names
        self.workloads = workloads

    @property
    def name(self):
        """Gets the name of this App.  # noqa: E501

        Name of the application  # noqa: E501

        :return: The name of this App.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this App.

        Name of the application  # noqa: E501

        :param name: The name of this App.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def namespace(self):
        """Gets the namespace of this App.  # noqa: E501


        :return: The namespace of this App.  # noqa: E501
        :rtype: Namespace
        """
        return self._namespace

    @namespace.setter
    def namespace(self, namespace):
        """Sets the namespace of this App.


        :param namespace: The namespace of this App.  # noqa: E501
        :type: Namespace
        """
        if namespace is None:
            raise ValueError("Invalid value for `namespace`, must not be `None`")  # noqa: E501

        self._namespace = namespace

    @property
    def runtimes(self):
        """Gets the runtimes of this App.  # noqa: E501

        Runtimes and associated dashboards  # noqa: E501

        :return: The runtimes of this App.  # noqa: E501
        :rtype: list[Runtime]
        """
        return self._runtimes

    @runtimes.setter
    def runtimes(self, runtimes):
        """Sets the runtimes of this App.

        Runtimes and associated dashboards  # noqa: E501

        :param runtimes: The runtimes of this App.  # noqa: E501
        :type: list[Runtime]
        """

        self._runtimes = runtimes

    @property
    def service_names(self):
        """Gets the service_names of this App.  # noqa: E501

        List of service names linked with an application  # noqa: E501

        :return: The service_names of this App.  # noqa: E501
        :rtype: list[str]
        """
        return self._service_names

    @service_names.setter
    def service_names(self, service_names):
        """Sets the service_names of this App.

        List of service names linked with an application  # noqa: E501

        :param service_names: The service_names of this App.  # noqa: E501
        :type: list[str]
        """
        if service_names is None:
            raise ValueError("Invalid value for `service_names`, must not be `None`")  # noqa: E501

        self._service_names = service_names

    @property
    def workloads(self):
        """Gets the workloads of this App.  # noqa: E501

        Workloads for a given application  # noqa: E501

        :return: The workloads of this App.  # noqa: E501
        :rtype: list[WorkloadItem]
        """
        return self._workloads

    @workloads.setter
    def workloads(self, workloads):
        """Sets the workloads of this App.

        Workloads for a given application  # noqa: E501

        :param workloads: The workloads of this App.  # noqa: E501
        :type: list[WorkloadItem]
        """
        if workloads is None:
            raise ValueError("Invalid value for `workloads`, must not be `None`")  # noqa: E501

        self._workloads = workloads

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(App, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, App):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import kps_api
from api.user_api import UserApi  # noqa: E501
from kps_api.rest import ApiException


class TestUserApi(unittest.TestCase):
    """UserApi unit test stubs"""

    def setUp(self):
        self.api = api.user_api.UserApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_is_email_available(self):
        """Test case for is_email_available

        Check if the given email is available for create user.  # noqa: E501
        """
        pass

    def test_project_get_users_v2(self):
        """Test case for project_get_users_v2

        Get project users.  # noqa: E501
        """
        pass

    def test_user_create_v2(self):
        """Test case for user_create_v2

        Create user.  # noqa: E501
        """
        pass

    def test_user_delete_v2(self):
        """Test case for user_delete_v2

        Delete user by ID.  # noqa: E501
        """
        pass

    def test_user_get_v2(self):
        """Test case for user_get_v2

        Get user by ID.  # noqa: E501
        """
        pass

    def test_user_list_v2(self):
        """Test case for user_list_v2

        Get users.  # noqa: E501
        """
        pass

    def test_user_update_v3(self):
        """Test case for user_update_v3

        Update user with a given ID.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six
from kps_api.models.ml_model_version_status import MLModelVersionStatus  # noqa: F401,E501


class MLModelStatus(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'created_at': 'datetime',
        'edge_id': 'str',
        'model_id': 'str',
        'model_status': 'list[MLModelVersionStatus]',
        'project_id': 'str',
        'tenant_id': 'str',
        'updated_at': 'datetime',
        'version': 'float'
    }

    attribute_map = {
        'created_at': 'createdAt',
        'edge_id': 'edgeId',
        'model_id': 'modelId',
        'model_status': 'modelStatus',
        'project_id': 'projectId',
        'tenant_id': 'tenantId',
        'updated_at': 'updatedAt',
        'version': 'version'
    }

    def __init__(self, created_at=None, edge_id=None, model_id=None, model_status=None, project_id=None, tenant_id=None, updated_at=None, version=None):  # noqa: E501
        """MLModelStatus - a model defined in Swagger"""  # noqa: E501
        self._created_at = None
        self._edge_id = None
        self._model_id = None
        self._model_status = None
        self._project_id = None
        self._tenant_id = None
        self._updated_at = None
        self._version = None
        self.discriminator = None
        if created_at is not None:
            self.created_at = created_at
        if edge_id is not None:
            self.edge_id = edge_id
        if model_id is not None:
            self.model_id = model_id
        if model_status is not None:
            self.model_status = model_status
        if project_id is not None:
            self.project_id = project_id
        if tenant_id is not None:
            self.tenant_id = tenant_id
        if updated_at is not None:
            self.updated_at = updated_at
        if version is not None:
            self.version = version

    @property
    def created_at(self):
        """Gets the created_at of this MLModelStatus.  # noqa: E501


        :return: The created_at of this MLModelStatus.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this MLModelStatus.


        :param created_at: The created_at of this MLModelStatus.  # noqa: E501
        :type: datetime
        """

        self._created_at = created_at

    @property
    def edge_id(self):
        """Gets the edge_id of this MLModelStatus.  # noqa: E501


        :return: The edge_id of this MLModelStatus.  # noqa: E501
        :rtype: str
        """
        return self._edge_id

    @edge_id.setter
    def edge_id(self, edge_id):
        """Sets the edge_id of this MLModelStatus.


        :param edge_id: The edge_id of this MLModelStatus.  # noqa: E501
        :type: str
        """

        self._edge_id = edge_id

    @property
    def model_id(self):
        """Gets the model_id of this MLModelStatus.  # noqa: E501


        :return: The model_id of this MLModelStatus.  # noqa: E501
        :rtype: str
        """
        return self._model_id

    @model_id.setter
    def model_id(self, model_id):
        """Sets the model_id of this MLModelStatus.


        :param model_id: The model_id of this MLModelStatus.  # noqa: E501
        :type: str
        """

        self._model_id = model_id

    @property
    def model_status(self):
        """Gets the model_status of this MLModelStatus.  # noqa: E501


        :return: The model_status of this MLModelStatus.  # noqa: E501
        :rtype: list[MLModelVersionStatus]
        """
        return self._model_status

    @model_status.setter
    def model_status(self, model_status):
        """Sets the model_status of this MLModelStatus.


        :param model_status: The model_status of this MLModelStatus.  # noqa: E501
        :type: list[MLModelVersionStatus]
        """

        self._model_status = model_status

    @property
    def project_id(self):
        """Gets the project_id of this MLModelStatus.  # noqa: E501


        :return: The project_id of this MLModelStatus.  # noqa: E501
        :rtype: str
        """
        return self._project_id

    @project_id.setter
    def project_id(self, project_id):
        """Sets the project_id of this MLModelStatus.


        :param project_id: The project_id of this MLModelStatus.  # noqa: E501
        :type: str
        """

        self._project_id = project_id

    @property
    def tenant_id(self):
        """Gets the tenant_id of this MLModelStatus.  # noqa: E501


        :return: The tenant_id of this MLModelStatus.  # noqa: E501
        :rtype: str
        """
        return self._tenant_id

    @tenant_id.setter
    def tenant_id(self, tenant_id):
        """Sets the tenant_id of this MLModelStatus.


        :param tenant_id: The tenant_id of this MLModelStatus.  # noqa: E501
        :type: str
        """

        self._tenant_id = tenant_id

    @property
    def updated_at(self):
        """Gets the updated_at of this MLModelStatus.  # noqa: E501


        :return: The updated_at of this MLModelStatus.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this MLModelStatus.


        :param updated_at: The updated_at of this MLModelStatus.  # noqa: E501
        :type: datetime
        """

        self._updated_at = updated_at

    @property
    def version(self):
        """Gets the version of this MLModelStatus.  # noqa: E501


        :return: The version of this MLModelStatus.  # noqa: E501
        :rtype: float
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this MLModelStatus.


        :param version: The version of this MLModelStatus.  # noqa: E501
        :type: float
        """

        self._version = version

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(MLModelStatus, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MLModelStatus):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
